==> gallery_1.5.orig.tar.gz: gallery-1.5.orig/locale/lt_LT/lt_LT-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Id: lt_LT-nls.php,v 1.8.2.3 2005/03/23 08:56:35 cryptographite Exp $
 *
 * Version: 1.5
 */
/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz 
 * (jens@peino.de)
 *
 */

/**
 ** Native languagename
 **/
	$nls['language']['lt_LT'] = 		'Lietuvi&#x0173;';

/**
 ** Alias for languages with different browser and gettext codes
 **/

	$nls['alias']['lt'] = 			'lt_LT';

/**
 ** Alias for languages which we substitte or send by NUKE
 **/

	$nls['alias']['lt_LT.ISO8859-4'] =	'lt_LT' ;
	$nls['alias']['lt_LT.ISO8859-13'] =	'lt_LT' ;
	
/**
 ** Charsets
 **
 **/	
	
	$nls['charset']['lt_LT'] = 		'windows-1257';
?>

==> gallery_1.5.1.orig.tar.gz: gallery-1.5.1.orig/locale/lt_LT/lt_LT-nls.php <==
<?php
/*
 * Gallery - a web based photo album viewer and editor
 * Copyright (C) 2000-2005 Bharat Mediratta
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * $Id: lt_LT-nls.php,v 1.12.2.2 2005/09/12 22:41:04 dmolavi Exp $
  */
 
/**
 * @version	1.5.1
 * @package	Languagepack
 * @subpackage	Lithuanian
 */

/**
 * NLS (National Language System) array.
 *
 * The basic idea and values was taken from then Horde Framework (http://horde.org)
 * The original filename was horde/config/nls.php.dist.
 * The modifications to fit it for Gallery were made by Jens Tkotz.
 * (jens@peino.de)
 */

/**
 * Native languagename
 */
	$nls['language']['lt_LT'] = 		'Lietuvi&#x0173;';

/**
 * Aliases for languages with different browser and gettext codes
 */
	$nls['alias']['lt'] = 			'lt_LT';

/**
 * Aliases for languages which we substitte or send by NUKE, GeekLog or Mambo
 */
	$nls['alias']['lt_LT.ISO8859-4'] =	'lt_LT' ;
	$nls['alias']['lt_LT.ISO8859-13'] =	'lt_LT' ;
	$nls['alias']['lithuanian'] =		'lt_LT' ;

/**
 * Charset
 */
	$nls['charset']['lt_LT'] = 		'windows-1257';

?>
